<?php
/**
 * Activatelife Admin Class
 *
 * @package  activatelife
 * @since    2.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Activatelife_Admin' ) ) :
	/**
	 * The Activatelife admin class
	 */
	class Activatelife_Admin {

		/**
		 * Setup class.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			add_action( 'admin_menu', array( $this, 'welcome_register_menu' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'welcome_style' ) );
		}

		/**
		 * Load welcome screen css
		 *
		 * @param string $hook_suffix the current page hook suffix.
		 * @return void
		 * @since  1.4.4
		 */
		public function welcome_style( $hook_suffix ) {
			global $activatelife_version;

			if ( 'appearance_page_activatelife-welcome' === $hook_suffix ) {
				wp_enqueue_style( 'activatelife-welcome-screen', get_template_directory_uri() . '/assets/css/admin/welcome-screen/welcome.css', $activatelife_version );
				wp_style_add_data( 'activatelife-welcome-screen', 'rtl', 'replace' );
			}
		}

		/**
		 * Creates the dashboard page
		 *
		 * @see  add_theme_page()
		 * @since 1.0.0
		 */
		public function welcome_register_menu() {
			add_theme_page( 'Activatelife', 'Activatelife', 'activate_plugins', 'activatelife-welcome', array( $this, 'activatelife_welcome_screen' ) );
		}

		/**
		 * The welcome screen
		 *
		 * @since 1.0.0
		 */
		public function activatelife_welcome_screen() {
			require_once ABSPATH . 'wp-load.php';
			require_once ABSPATH . 'wp-admin/admin.php';
			require_once ABSPATH . 'wp-admin/admin-header.php';

			global $activatelife_version;
			?>

			<div class="activatelife-wrap">


				<div class="activatelife-logo">
					<img src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/images/admin/activatelife-icon.svg" alt="Activatelife" />
				</div>

				<div class="activatelife-intro">
					<p class="activatelife-welcome-nav__version">Activatelife <?php echo esc_attr( $activatelife_version ); ?></p>
					<?php
					/**
					 * Display a different message when the user visits this page when returning from the guided tour
					 */
					$referrer = wp_get_referer();

					echo '<h1>' . sprintf( esc_attr__( '%1$sWelcome to Activatelife! %2$s ', 'activatelife' ), '<span>', '</span>' ) . '</h1>';
					echo '<p>' . esc_attr__( 'Hello! You might be interested in the following Activatelife extensions and designs.', 'activatelife' ) . '</p>';
					?>

				</div>

				<div class="activatelife-welcome">
					<div class="activatelife-welcome__column activatelife-support">
						<h3><?php esc_attr_e( 'Support Cover', 'activatelife' ); ?></h3>
						<span class="bundle-image">
							<img src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/images/admin/welcome-screen/support.png" alt="Activatelife Support" />
						</span>

						<p>
							<?php esc_attr_e( 'We\'ll give you a reply within 24 hours except during weekends.', 'activatelife' ); ?>
						</p>

						<div class="box-footer">
							<a href="<?php echo esc_url('https://themelexus.ticksy.com');?>" class="activatelife-button" target="_blank"><?php esc_attr_e( 'Submit Ticket', 'activatelife' ); ?></a>
						</div>
					</div>

					<div class="activatelife-welcome__column activatelife-documentation">
						<h3><?php esc_attr_e( 'Documentation', 'activatelife' ); ?></h3>
						<span class="bundle-image">
							<img src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/images/admin/welcome-screen/documentation.png" alt="Activatelife Documentation" />
						</span>

						<p>
							<?php esc_attr_e( 'We\'ll give you a reply within 24 hours except during weekends.', 'activatelife' ); ?>
						</p>

						<div class="box-footer">
							<a href="<?php echo esc_url('https://wpdocs.gitbook.io/activatelife')?>" class="activatelife-button" target="_blank"><?php esc_attr_e( 'Explore Now', 'activatelife' ); ?></a>
						</div>
					</div>

					<div class="activatelife-welcome__column activatelife-information">
						<h3><?php esc_attr_e( 'Alternate designs', 'activatelife' ); ?></h3>
						<span class="bundle-image">
							<img src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/images/admin/welcome-screen/information.png" alt="Activatelife Information" />
						</span>
						<p>
							<?php esc_attr_e( 'Checkout our site and social for more information.', 'activatelife' ); ?>
						</p>
						<div class="box-footer">
							<ul class="list-social">
								<li>
									<a href="https://themeforest.net/user/themelexus/portfolio">
										<img src="http://localhost/wordpress/nouvhotel/wp-content/themes/nouvhotel/inc/admin/images/social/evanto.png" alt="Envato">
									</a>
								</li>
								<li>
									<a href="https://www.facebook.com/themelexus/">
										<img src="http://localhost/wordpress/nouvhotel/wp-content/themes/nouvhotel/inc/admin/images/social/facebook.png" alt="Facebook">
									</a>
								</li>
								<li>
									<a href="https://twitter.com/opalwordpress">
										<img src="http://localhost/wordpress/nouvhotel/wp-content/themes/nouvhotel/inc/admin/images/social/twiter.png" alt="Tweeter">
									</a>
								</li>
								<li>
									<a href="https://www.youtube.com/channel/UCEVKfaT81jFq4HE1Yky99GA">
										<img src="http://localhost/wordpress/nouvhotel/wp-content/themes/nouvhotel/inc/admin/images/social/youtube.png" alt="Youtube">
									</a>
								</li>
								<li>
									<a href="mailto:themelexus@gmail.com">
										<img src="http://localhost/wordpress/nouvhotel/wp-content/themes/nouvhotel/inc/admin/images/social/email.png" alt="Email">
									</a>
								</li>
							</ul>
						</div>
					</div>
				</div>

			</div>
			<?php
		}

		/**
		 * Welcome screen intro
		 *
		 * @since 1.0.0
		 */
		public function welcome_intro() {
			require_once get_template_directory() . '/inc/admin/welcome-screen/component-intro.php';
		}

		/**
		 * Output a button that will install or activate a plugin if it doesn't exist, or display a disabled button if the
		 * plugin is already activated.
		 *
		 * @param string $plugin_slug The plugin slug.
		 * @param string $plugin_file The plugin file.
		 */
		public function install_plugin_button( $plugin_slug, $plugin_file ) {
			if ( current_user_can( 'install_plugins' ) && current_user_can( 'activate_plugins' ) ) {
				if ( is_plugin_active( $plugin_slug . '/' . $plugin_file ) ) {
					// The plugin is already active.
					$button = array(
						'message' => esc_attr__( 'Activated', 'activatelife' ),
						'url'     => '#',
						'classes' => 'disabled',
					);
				} elseif ( $this->_is_plugin_installed( $plugin_slug ) ) {
					$url = $this->_is_plugin_installed( $plugin_slug );

					// The plugin exists but isn't activated yet.
					$button = array(
						'message' => esc_attr__( 'Activate', 'activatelife' ),
						'url'     => $url,
						'classes' => 'activate-now',
					);
				} else {
					// The plugin doesn't exist.
					$url    = wp_nonce_url(
						add_query_arg(
							array(
								'action' => 'install-plugin',
								'plugin' => $plugin_slug,
							), self_admin_url( 'update.php' )
						), 'install-plugin_' . $plugin_slug
					);
					$button = array(
						'message' => esc_attr__( 'Install now', 'activatelife' ),
						'url'     => $url,
						'classes' => ' install-now install-' . $plugin_slug,
					);
				}
				?>
				<a href="<?php echo esc_url( $button['url'] ); ?>" class="activatelife-button <?php echo esc_attr( $button['classes'] ); ?>" data-originaltext="<?php echo esc_attr( $button['message'] ); ?>" data-slug="<?php echo esc_attr( $plugin_slug ); ?>" aria-label="<?php echo esc_attr( $button['message'] ); ?>"><?php echo esc_attr( $button['message'] ); ?></a>
				<a href="https://wordpress.org/plugins/<?php echo esc_attr( $plugin_slug ); ?>" target="_blank"><?php esc_attr_e( 'Learn more', 'activatelife' ); ?></a>
				<?php
			}
		}

		/**
		 * Check if a plugin is installed and return the url to activate it if so.
		 *
		 * @param string $plugin_slug The plugin slug.
		 */
		public function _is_plugin_installed( $plugin_slug ) {
			if ( file_exists( WP_PLUGIN_DIR . '/' . $plugin_slug ) ) {
				$plugins = get_plugins( '/' . $plugin_slug );
				if ( ! empty( $plugins ) ) {
					$keys        = array_keys( $plugins );
					$plugin_file = $plugin_slug . '/' . $keys[0];
					$url         = wp_nonce_url(
						add_query_arg(
							array(
								'action' => 'activate',
								'plugin' => $plugin_file,
							), admin_url( 'plugins.php' )
						), 'activate-plugin_' . $plugin_file
					);
					return $url;
				}
			}
			return false;
		}
		/**
		 * Welcome screen enhance section
		 *
		 * @since 1.5.2
		 */
		public function welcome_enhance() {
			require_once get_template_directory() . '/inc/admin/welcome-screen/component-enhance.php';
		}

		/**
		 * Welcome screen contribute section
		 *
		 * @since 1.5.2
		 */
		public function welcome_contribute() {
			require_once get_template_directory() . '/inc/admin/welcome-screen/component-contribute.php';
		}

		/**
		 * Get product data from json
		 *
		 * @param  string $url       URL to the json file.
		 * @param  string $transient Name the transient.
		 * @return [type]            [description]
		 */
		public function get_activatelife_product_data( $url, $transient ) {
			$raw_products = wp_safe_remote_get( $url );
			$products     = json_decode( wp_remote_retrieve_body( $raw_products ) );

			if ( ! empty( $products ) ) {
				set_transient( $transient, $products, DAY_IN_SECONDS );
			}

			return $products;
		}
	}

endif;

return new Activatelife_Admin();
