<?php
/**
 * Activatelife template functions.
 *
 * @package activatelife
 */

if ( ! function_exists( 'activatelife_display_comments' ) ) {
	/**
	 * Activatelife display comments
	 *
	 * @since  1.0.0
	 */
	function activatelife_display_comments() {
		// If comments are open or we have at least one comment, load up the comment template.
		if ( comments_open() || 0 !== intval( get_comments_number() ) ) :
			comments_template();
		endif;
	}
}

if ( ! function_exists( 'activatelife_comment' ) ) {
	/**
	 * Activatelife comment template
	 *
	 * @param array $comment the comment array.
	 * @param array $args the comment args.
	 * @param int   $depth the comment depth.
	 * @since 1.0.0
	 */
	function activatelife_comment( $comment, $args, $depth ) {
		if ( 'div' === $args['style'] ) {
			$tag       = 'div';
			$add_below = 'comment';
		} else {
			$tag       = 'li';
			$add_below = 'div-comment';
		}
		?>
		<<?php echo esc_attr( $tag ); ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?> id="comment-<?php comment_ID(); ?>">
		<div class="comment-body">
		<div class="comment-meta commentmetadata">
			<div class="comment-author vcard">
			<?php echo get_avatar( $comment, 128 ); ?>
			<?php printf( wp_kses_post( '<cite class="fn">%s</cite>', 'activatelife' ), get_comment_author_link() ); ?>
			</div>
			<?php if ( '0' === $comment->comment_approved ) : ?>
				<em class="comment-awaiting-moderation"><?php esc_attr_e( 'Your comment is awaiting moderation.', 'activatelife' ); ?></em>
				<br />
			<?php endif; ?>

			<a href="<?php echo esc_url( htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ); ?>" class="comment-date">
				<?php echo '<time datetime="' . get_comment_date( 'c' ) . '">' . get_comment_date() . '</time>'; ?>
			</a>
		</div>
		<?php if ( 'div' !== $args['style'] ) : ?>
		<div id="div-comment-<?php comment_ID(); ?>" class="comment-content">
		<?php endif; ?>
		<div class="comment-text">
		<?php comment_text(); ?>
		</div>
		<div class="reply">
		<?php
		comment_reply_link(
			array_merge(
				$args, array(
					'add_below' => $add_below,
					'depth'     => $depth,
					'max_depth' => $args['max_depth'],
				)
			)
		);
		?>
		<?php edit_comment_link( __( 'Edit', 'activatelife' ), '  ', '' ); ?>
		</div>
		</div>
		<?php if ( 'div' !== $args['style'] ) : ?>
		</div>
		<?php endif; ?>
		<?php
	}
}

if ( ! function_exists( 'activatelife_footer_widgets' ) ) {
	/**
	 * Display the footer widget regions.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function activatelife_footer_widgets() {
		$rows    = intval( apply_filters( 'activatelife_footer_widget_rows', 1 ) );
		$regions = intval( apply_filters( 'activatelife_footer_widget_columns', 4 ) );

		for ( $row = 1; $row <= $rows; $row++ ) :

			// Defines the number of active columns in this footer row.
			for ( $region = $regions; 0 < $region; $region-- ) {
				if ( is_active_sidebar( 'footer-' . esc_attr( $region + $regions * ( $row - 1 ) ) ) ) {
					$columns = $region;
					break;
				}
			}

			if ( isset( $columns ) ) :
				?>
				<div class=<?php echo '"footer-widgets row-' . esc_attr( $row ) . ' col-' . esc_attr( $columns ) . ' fix"'; ?>>
				<?php
				for ( $column = 1; $column <= $columns; $column++ ) :
					$footer_n = $column + $regions * ( $row - 1 );

					if ( is_active_sidebar( 'footer-' . esc_attr( $footer_n ) ) ) :
						?>
					<div class="block footer-widget-<?php echo esc_attr( $column ); ?>">
						<?php dynamic_sidebar( 'footer-' . esc_attr( $footer_n ) ); ?>
					</div>
						<?php
					endif;
				endfor;
				?>
			</div><!-- .footer-widgets.row-<?php echo esc_attr( $row ); ?> -->
				<?php
				unset( $columns );
			endif;
		endfor;
	}
}


if ( ! function_exists( 'activatelife_credit' ) ) {
	/**
	 * Display the theme credit
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function activatelife_credit() {
		$content =  sprintf(__('Copyright &copy; %2s %1s,  All rights reserved', 'activatelife'), get_bloginfo( 'name' ), date( 'Y' ));
		?>
		<div class="site-info-wrap">
			<div class="col-full">
				<div class="site-info">
					<?php echo esc_html( apply_filters( 'activatelife_copyright_text', $content) ); ?>
				</div><!-- .site-info -->
			</div><!-- .col-full -->
		</div><!-- .ite-info-wrap -->
		<?php
	}
}

if ( ! function_exists( 'activatelife_site_branding' ) ) {
	/**
	 * Site branding wrapper and display
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function activatelife_site_branding() {
		?>
		<div class="site-branding">
			<?php activatelife_site_title_or_logo(); ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'activatelife_site_title_or_logo' ) ) {
	/**
	 * Display the site title or logo
	 *
	 * @since 2.1.0
	 * @param bool $echo Echo the string or return it.
	 * @return string
	 */
	function activatelife_site_title_or_logo( $echo = true ) {
		if ( function_exists( 'the_custom_logo' ) && has_custom_logo() ) {
			$logo = get_custom_logo();
			$html = is_home() ? '<h1 class="logo">' . $logo . '</h1>' : $logo;
		} else {
			$tag = is_home() ? 'h1' : 'div';

			$html = '<' . esc_attr( $tag ) . ' class="beta site-title"><a href="' . esc_url( home_url( '/' ) ) . '" rel="home">' . esc_html( get_bloginfo( 'name' ) ) . '</a></' . esc_attr( $tag ) . '>';

			if ( '' !== get_bloginfo( 'description' ) ) {
				$html .= '<p class="site-description">' . esc_html( get_bloginfo( 'description', 'display' ) ) . '</p>';
			}
		}

		if ( ! $echo ) {
			return $html;
		}

		echo $html; // WPCS: XSS ok.
	}
}

if ( ! function_exists( 'activatelife_primary_navigation' ) ) {
	/**
	 * Display Primary Navigation
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function activatelife_primary_navigation() {
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="<?php esc_html_e( 'Primary Navigation', 'activatelife' ); ?>">
			<button id="handheld-toggle" class="handheld-toggle" aria-controls="site-navigation" aria-expanded="false">
				<?php load_inline_svg('menu.svg');?>
				<span class="screen-reader-text"><?php echo esc_attr( apply_filters( 'activatelife_menu_toggle_text', __( 'Menu', 'activatelife' ) ) ); ?></span>
			</button>

			<?php
			wp_nav_menu(
				array(
					'theme_location'  => 'primary',
					'container_class' => 'primary-navigation',
				)
			);
			?>
		</nav><!-- #site-navigation -->
		<?php
	}
}

if ( ! function_exists( 'activatelife_skip_links' ) ) {
	/**
	 * Skip links
	 *
	 * @since  1.4.1
	 * @return void
	 */
	function activatelife_skip_links() {
		?>
		<a class="skip-link screen-reader-text" href="#site-navigation"><?php esc_attr_e( 'Skip to navigation', 'activatelife' ); ?></a>
		<a class="skip-link screen-reader-text" href="#content"><?php esc_attr_e( 'Skip to content', 'activatelife' ); ?></a>
		<?php
	}
}

if ( ! function_exists( 'activatelife_search_toggle' ) ) {
	/**
	 * Search toggle
	 *
	 * @since  1.0.1
	 * @return void
	 */
	function activatelife_search_toggle() {
		?>
		<button id="header__search-toggle" class="header__search-toggle" data-toggle-target=".search-modal" data-set-focus=".search-modal .search-form__input" type="button" aria-controls="js-site-search">
			<div class="search-toggle-icon">
				<?php load_inline_svg( 'search.svg' ); ?>
			</div>
			<span class="screen-reader-text"> <?php echo esc_html__( 'Search Toggle', 'activatelife' ) ?> </span>
		</button>
		<?php
	}
}

if ( ! function_exists( 'activatelife_search_modal' ) ) {
	/**
	 * Search
	 *
	 * @since  1.0.1
	 * @return void
	 */
	function activatelife_search_modal() {
		get_template_part( 'template-parts/modal-search' );
	}
}

if ( ! function_exists( 'activatelife_homepage_header' ) ) {
	/**
	 * Display the page header without the featured image
	 *
	 * @since 1.0.0
	 */
	function activatelife_homepage_header() {
		edit_post_link( __( 'Edit this section', 'activatelife' ), '', '', '', 'button activatelife-hero__button-edit' );
		?>
		<header class="entry-header">
			<?php
			the_title( '<h1 class="entry-title">', '</h1>' );
			?>
		</header><!-- .entry-header -->
		<?php
	}
}

if ( ! function_exists( 'activatelife_page_header' ) ) {
	/**
	 * Display the page header
	 *
	 * @since 1.0.0
	 */
	function activatelife_page_header() {
		if ( is_front_page() && is_page_template( 'template-fullwidth.php' ) ) {
			return;
		}

		?>
		<header class="entry-header">
			<?php
			activatelife_post_thumbnail( 'full' );
			the_title( '<h1 class="entry-title">', '</h1>' );
			?>
		</header><!-- .entry-header -->
		<?php
	}
}

if ( ! function_exists( 'activatelife_page_content' ) ) {
	/**
	 * Display the post content
	 *
	 * @since 1.0.0
	 */
	function activatelife_page_content() {
		?>
		<div class="entry-content">
			<?php the_content(); ?>
			<?php
				wp_link_pages(
					array(
						'before' => '<div class="page-links">' . __( 'Pages:', 'activatelife' ),
						'after'  => '</div>',
					)
				);
			?>
		</div><!-- .entry-content -->
		<?php
	}
}

if ( ! function_exists( 'activatelife_post_header' ) ) {
	/**
	 * Display the post header with a link to the single post
	 *
	 * @since 1.0.0
	 */
	function activatelife_post_header() {
		?>
		<header class="entry-header">
		<?php

		/**
		 * Functions hooked in to activatelife_post_header_before action.
		 *
		 * @see activatelife_post_meta - 10
		 */
		do_action( 'activatelife_post_header_before' );

		if ( is_single() ) {
			the_title( '<h1 class="entry-title">', '</h1>' );
		} else {
			the_title( sprintf( '<h2 class="alpha entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' );
		}

		do_action( 'activatelife_post_header_after' );
		?>
		</header><!-- .entry-header -->
		<?php
	}
}

if ( ! function_exists( 'activatelife_post_content' ) ) {
	/**
	 * Display the post content with a link to the single post
	 *
	 * @since 1.0.0
	 */
	function activatelife_post_content() {
		?>
		<div class="entry-content">
		<?php

		/**
		 * Functions hooked in to activatelife_post_content_before action.
		 *
		 * @see activatelife_post_thumbnail - 10
		 */
		do_action( 'activatelife_post_content_before' );

		the_content(
			sprintf(
				/* translators: %s: post title */
				__( 'Continue reading %s', 'activatelife' ),
				'<span class="screen-reader-text">' . get_the_title() . '</span>'
			)
		);

		do_action( 'activatelife_post_content_after' );

		wp_link_pages(
			array(
				'before' => '<div class="page-links">' . __( 'Pages:', 'activatelife' ),
				'after'  => '</div>',
			)
		);
		?>
		</div><!-- .entry-content -->
		<?php
	}
}

if ( ! function_exists( 'activatelife_post_meta' ) ) {
	/**
	 * Display the post meta
	 *
	 * @since 1.0.0
	 */
	function activatelife_post_meta() {
		if ( 'post' !== get_post_type() ) {
			return;
		}

		// Posted on.
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

		$output_time_string = sprintf( '<a href="%1$s" rel="bookmark">%2$s</a>', esc_url( get_permalink() ), $time_string );

		$posted_on = '
			<span class="posted-on">' .
			/* translators: %s: post date */
			sprintf( __( 'Posted on %s', 'activatelife' ), $output_time_string ) .
			'</span>';

		// Author.
		$author = sprintf(
			'<span class="post-author">%1$s <a href="%2$s" class="url fn" rel="author">%3$s</a></span>',
			__( 'by', 'activatelife' ),
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_html( get_the_author() )
		);

		// Comments.
		$comments = '';

		if ( ! post_password_required() && ( comments_open() || 0 !== intval( get_comments_number() ) ) ) {
			$comments_number = get_comments_number_text( __( 'Leave a comment', 'activatelife' ), __( '1 Comment', 'activatelife' ), __( '% Comments', 'activatelife' ) );

			$comments = sprintf(
				'<span class="post-comments">&mdash; <a href="%1$s">%2$s</a></span>',
				esc_url( get_comments_link() ),
				$comments_number
			);
		}

		echo wp_kses(
			sprintf( '%1$s %2$s %3$s', $posted_on, $author, $comments ), array(
				'span' => array(
					'class' => array(),
				),
				'a'    => array(
					'href'  => array(),
					'title' => array(),
					'rel'   => array(),
				),
				'time' => array(
					'datetime' => array(),
					'class'    => array(),
				),
			)
		);
	}
}

if ( ! function_exists( 'activatelife_edit_post_link' ) ) {
	/**
	 * Display the edit link
	 *
	 * @since 2.5.0
	 */
	function activatelife_edit_post_link() {
		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'activatelife' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<div class="edit-link">',
			'</div>'
		);
	}
}

if ( ! function_exists( 'activatelife_post_taxonomy' ) ) {
	/**
	 * Display the post taxonomies
	 *
	 * @since 2.4.0
	 */
	function activatelife_post_taxonomy() {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( __( ', ', 'activatelife' ) );

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', __( ', ', 'activatelife' ) );
		?>

		<aside class="entry-taxonomy">
			<?php if ( $categories_list ) : ?>
			<div class="cat-links">
				<?php echo esc_html( _n( 'Category:', 'Categories:', count( get_the_category() ), 'activatelife' ) ); ?> <?php echo wp_kses_post( $categories_list ); ?>
			</div>
			<?php endif; ?>

			<?php if ( $tags_list ) : ?>
			<div class="tags-links">
				<?php echo esc_html( _n( 'Tag:', 'Tags:', count( get_the_tags() ), 'activatelife' ) ); ?> <?php echo wp_kses_post( $tags_list ); ?>
			</div>
			<?php endif; ?>
		</aside>

		<?php
	}
}

if ( ! function_exists( 'activatelife_paging_nav' ) ) {
	/**
	 * Display navigation to next/previous set of posts when applicable.
	 */
	function activatelife_paging_nav() {
		global $wp_query;

		$args = array(
			'type'      => 'list',
			'next_text' => _x( 'Next', 'Next post', 'activatelife' ),
			'prev_text' => _x( 'Previous', 'Previous post', 'activatelife' ),
		);

		the_posts_pagination( $args );
	}
}

if ( ! function_exists( 'activatelife_post_nav' ) ) {
	/**
	 * Display navigation to next/previous post when applicable.
	 */
	function activatelife_post_nav() {
		$args = array(
			'next_text' => '<span class="screen-reader-text">' . esc_html__( 'Next post:', 'activatelife' ) . ' </span>%title',
			'prev_text' => '<span class="screen-reader-text">' . esc_html__( 'Previous post:', 'activatelife' ) . ' </span>%title',
		);
		the_post_navigation( $args );
	}
}

if ( ! function_exists( 'activatelife_posted_on' ) ) {
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 *
	 * @deprecated 2.4.0
	 */
	function activatelife_posted_on() {
		_deprecated_function( 'activatelife_posted_on', '2.4.0' );
	}
}

if ( ! function_exists( 'activatelife_homepage_content' ) ) {
	/**
	 * Display homepage content
	 * Hooked into the `homepage` action in the homepage template
	 *
	 * @since  1.0.0
	 * @return  void
	 */
	function activatelife_homepage_content() {
		while ( have_posts() ) {
			the_post();

			get_template_part( 'content', 'homepage' );

		} // end of the loop.
	}
}

if ( ! function_exists( 'activatelife_get_sidebar' ) ) {
	/**
	 * Display activatelife sidebar
	 *
	 * @uses get_sidebar()
	 * @since 1.0.0
	 */
	function activatelife_get_sidebar() {
		get_sidebar();
	}
}

if ( ! function_exists( 'activatelife_post_thumbnail' ) ) {
	/**
	 * Display post thumbnail
	 *
	 * @var $size thumbnail size. thumbnail|medium|large|full|$custom
	 * @uses has_post_thumbnail()
	 * @uses the_post_thumbnail
	 * @param string $size the post thumbnail size.
	 * @since 1.5.0
	 */
	function activatelife_post_thumbnail( $size = 'full' ) {
		if ( has_post_thumbnail() ) {
			the_post_thumbnail( $size );
		}
	}
}

if ( ! function_exists( 'activatelife_primary_navigation_wrapper' ) ) {
	/**
	 * The header extras wrapper
	 */
	function activatelife_header_extras_wrapper() {
		echo '<div class="site-extras">';
	}
}

if ( ! function_exists( 'activatelife_primary_navigation_wrapper_close' ) ) {
	/**
	 * The header extras wrapper close
	 */
	function activatelife_header_extras_wrapper_close() {
		echo '</div>';
	}
}

if ( ! function_exists( 'activatelife_header_container' ) ) {
	/**
	 * The header container
	 */
	function activatelife_header_container() {
		echo '<div class="col-full">';
	}
}

if ( ! function_exists( 'activatelife_header_container_close' ) ) {
	/**
	 * The header container close
	 */
	function activatelife_header_container_close() {
		echo '</div>';
	}
}

if ( ! function_exists( 'activatelife_footer_container' ) ) {
	/**
	 * The header container close
	 */
	function activatelife_footer_container() {
		echo '<div class="col-full">';
	}
}

if ( ! function_exists( 'activatelife_footer_container_close' ) ) {
	/**
	 * The header container close
	 */
	function activatelife_footer_container_close() {
		echo '</div>';
	}
}

/**
 * Output an inline SVG.
 *
 * @param string $filename The filename of the SVG you want to load.
 *
 * @return void
 */
function load_inline_svg( $filename ) {

	ob_start();

	locate_template(
		array(
			"assets/images/{$filename}",
		),
		true,
		false
	);

	echo wp_kses(
		ob_get_clean(),
		array_merge(
			wp_kses_allowed_html( 'post' ),
			array(
				'svg'  => array(
					'role'    => true,
					'width'   => true,
					'height'  => true,
					'fill'    => true,
					'xmlns'   => true,
					'viewbox' => true,
				),
				'path' => array(
					'd'              => true,
					'fill'           => true,
					'fill-rule'      => true,
					'stroke'         => true,
					'stroke-width'   => true,
					'stroke-linecap' => true,
				),
				'g'    => array(
					'd'    => true,
					'fill' => true,
				),
			)
		)
	);

}
if ( ! function_exists( 'activatelife_mobile_navigation' ) ) {
	/**
	 * Display Handheld Navigation
	 *
	 * @return void
	 * @since  1.0.0
	 */
	function activatelife_mobile_navigation() {
		?>
		<nav class="mobile-navigation" aria-label="<?php esc_html_e( 'Mobile Navigation', 'activatelife' ); ?>">
			<?php
			wp_nav_menu(
				array(
					'theme_location'  => 'handheld',
					'container_class' => 'handheld-navigation',
				)
			);
			?>
		</nav>
		<?php
	}
}

if ( ! function_exists( 'activatelife_mobile_nav' ) ) {
	function activatelife_mobile_nav() {
		if ( isset( get_nav_menu_locations()['handheld'] ) ) {
			?>
			<div class="handheld-navigation-wrap" id="handheld-wrap">
				<a href="#" id="handheld-close" class="handheld-close toggle-close ">
					<?php load_inline_svg('close.svg');?>
					<span class="screen-reader-text"><?php echo esc_html__('close', 'activatelife')?></span>
				</a>
				<?php
				activatelife_mobile_navigation();
				?>
			</div>
			<div id="handheld-overlay" class="handheld-overlay"></div>
			<?php
		}
	}
}
if ( ! function_exists( 'activatelife_language_switcher' ) ) {
	function activatelife_language_switcher() {
		$languages = apply_filters( 'wpml_active_languages', [] );
		if ( ! activatelife_is_extension_activated('SitePress') || count( $languages ) <= 0 ) {
			return;
		}
		?>
		<div class="activatelifelanguage-switcher">
			<ul class="menu">
				<li class="item">
					<span>
						<img width="18" height="12" src="<?php echo esc_url( $languages[ ICL_LANGUAGE_CODE ]['country_flag_url'] ) ?>" alt="<?php esc_attr( $languages[ ICL_LANGUAGE_CODE ]['default_locale'] ) ?>">
						<?php
						echo esc_html( $languages[ ICL_LANGUAGE_CODE ]['translated_name'] );
						?>
					</span>
					<ul class="sub-item">
						<?php
						foreach ( $languages as $key => $language ) {
							if ( ICL_LANGUAGE_CODE === $key ) {
								continue;
							}
							?>
							<li>
								<a href="<?php echo esc_url( $language['url'] ) ?>">
									<img width="18" height="12" src="<?php echo esc_url( $language['country_flag_url'] ) ?>" alt="<?php esc_attr( $language['default_locale'] ) ?>">
									<?php echo esc_html( $language['translated_name'] ); ?>
								</a>
							</li>
							<?php
						}
						?>
					</ul>
				</li>
			</ul>
		</div>
		<?php
	}
}

if ( ! function_exists( 'activatelife_language_switcher_mobile' ) ) {
	function activatelife_language_switcher_mobile() {
		$languages = apply_filters( 'wpml_active_languages', [] );
		if ( ! activatelife_is_extension_activated('SitePress') || count( $languages ) <= 0 ) {
			return;
		}
		?>
		<div class="activatelife-language-switcher-mobile">
            <span>
                <img width="18" height="12" src="<?php echo esc_url( $languages[ ICL_LANGUAGE_CODE ]['country_flag_url'] ) ?>" alt="<?php esc_attr( $languages[ ICL_LANGUAGE_CODE ]['default_locale'] ) ?>">
            </span>
			<?php
			foreach ( $languages as $key => $language ) {
				if ( ICL_LANGUAGE_CODE === $key ) {
					continue;
				}
				?>
				<a href="<?php echo esc_url( $language['url'] ) ?>">
					<img width="18" height="12" src="<?php echo esc_url( $language['country_flag_url'] ) ?>" alt="<?php esc_attr( $language['default_locale'] ) ?>">
				</a>
				<?php
			}
			?>
		</div>
		<?php
	}
}
